django-vintage v 0.1 — django-vintage v0.1 documentation

django-vintage v0.1 documentation

# django-vintage v 0.1

- Table of Contents
- index
  next

# django-vintage v 0.1

## About

The primary goals for Django Vintage are to:

- Archive pages from an old site to make them available
- Allow pointers to new resources that replace these
- Keep per-page metadata for search engines
- Use existing URL structure so redirecting from old site to archive is easy

## Contents

- Getting Started
  - Installation
  - Setting it up
  - Creating a page manually
  - Importing a page programatically
- Using templates
  - Where they go
  - The default template
  - How Django Vintage selects the template
  - The template context
- Customizing metadata
  - Creating the metadata form
- Reference
  - Settings
  - Model Reference
  - Importing a page with `process_url`